@@ -390,6 +390,18 @@ public:
      */
     void setVideoFps(int newFPS);
 
+    /**
+     * Get the splitting mode during movie export.
+     * @return The splitting mode.
+     */
+    int getMovieExportSplittingMode() const;
+
+    /**
+     * Set the splitting mode during movie export.
+     * @param newSplittingMode The splitting mode.
+     */
+    void setMovieExportSplittingMode(int newSplittingMode);
+
     /**
      * Get the use default output file flag of the project.
      * @return Use default output file flag.
@@ -1008,6 +1020,11 @@ private:
      */
     int videoFps;
 
+    /**
+     * Active splitting mode during movie export of the project.
+     */
+    int splittingMode;
+
     /**
      * Active use default output file flag of the project.
      */
