@@ -219,7 +219,7 @@ public:
     /**
      * @brief Default video encoder application for new installations
      */
-    const static int  ENCODERAPPLICATIONDEFAULT = noneEncoderApplication;
+    const static int  ENCODERAPPLICATIONDEFAULT = ffmpegApplication;
 
     /**
      * @brief Enum with all possible video output formats
@@ -258,6 +258,20 @@ public:
      */
     const static int  VIDEOFPSDEFAULT = 12;
 
+    /**
+     * @brief Enum with all possible video output formats
+     */
+    enum movieSplittingMode {
+        exportAsWholeMovie,        // All scenes and takes are united in one movie
+        exportAsSplittedOnScenes, // Movie is splitted up on several files - separate for each per scene
+        exportAsSplittedOnTakes   // Movie is splitted up on multiple files - separate for each per take
+    };
+
+    /**
+     * @brief Default splitting mode for new installations
+     */
+    const static int  MOVIESPLITTINGMODEDEFAULT = exportAsWholeMovie;
+
     /**
      * @brief Default usage of the default output file name for new installations
      */
@@ -654,6 +668,18 @@ public:
      */
     void setVideoFps(int newFPS);
 
+    /**
+     * Get the splitting mode during movie export.
+     * @return The splitting mode.
+     */
+    int getMovieExportSplittingMode();
+
+    /**
+     * Set the splitting mode during movie export.
+     * @param newSplittingMode The splitting mode.
+     */
+    void setMovieExportSplittingMode(int newSplittingMode);
+
     /**
      * Get the use default output file flag of the project.
      * @return Use default output file flag.
