@@ -66,6 +66,8 @@ AboutDialog::AboutDialog(Frontend *f,
     autorsText->setHtml(
                 "<p><b>" + tr("Main developers") + " - qStopMotion</b><br>"
                 "Ralf Lange &lt;ralf.lange@longsoft.de&gt;<br>"
+                "Dmitry Valento&lt;decobramegra@gmail.com&gt;<br>"
+                "Nikos &lt;kosnickx@gmail.com&gt;<br>"
                 "<p><b>" + tr("Main developers") + " - stopmotion for Linux</b><br>"
                 "Bjørn Erik Nilsen &lt;bjoern.nilsen@bjoernen.com&gt;<br>"
                 "Fredrik Berg Kjølstad &lt;fredrikbk@hotmail.com&gt;<br>"
@@ -88,6 +90,7 @@ AboutDialog::AboutDialog(Frontend *f,
                 "Ralf Lange &lt;ralf.lange@longsoft.de&gt; (" + tr("German") + ")<br>"
                 "Pavel Fric &lt;pavelfric@seznam.cz&gt; (" + tr("Czech") + ")<br>"
                 "Nikos &lt;kosnickx@gmail.com&gt; (" + tr("Greek") + ")<br>"
+                "Dmitry Valento&lt;decobramegra@gmail.com&gt; (" + tr("Russian") + ")<br>"
                 /*
                 "Gorazd Bizjak and Matej Lavreni &lt;info@zapstudio.net&gt; (" + tr("Slovenian") + ")<br>"
                 "José Jorge &lt;jjorge@free.fr&gt; (" + tr("Portuguese") + ")<br>"
@@ -133,77 +136,7 @@ AboutDialog::AboutDialog(Frontend *f,
 
     // Add line containing the OS version number
     version.append(tr("Operating system name and version: "));
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
-    // Windows version
-    switch(QSysInfo::WindowsVersion) {
-    case QSysInfo::WV_NT:
-        version.append("Windows NT (4.0)");
-        break;
-    case QSysInfo::WV_2000:
-        version.append("Windows 2000 (5.0)");
-        break;
-    case QSysInfo::WV_XP:
-        version.append("Windows XP (5.1)");
-        break;
-    case QSysInfo::WV_2003:
-        version.append("Windows 2003 (5.2)");
-        break;
-    case QSysInfo::WV_VISTA:
-        version.append("Windows Vista (6.0)");
-        break;
-    case QSysInfo::WV_WINDOWS7:
-        version.append("Windows 7 (6.1)");
-        break;
-    case QSysInfo::WV_WINDOWS8:
-        version.append("Windows 8 (6.2)");
-        break;
-    case QSysInfo::WV_WINDOWS8_1:
-        version.append("Windows 8.1 (6.3)");
-        break;
-    default:
-        version.append(tr("Unknown Windows OS"));
-        break;
-    }
-#endif
-#ifdef Q_OS_OSX
-    // Apple OS X version
-    switch(QSysInfo::MacintoshVersion) {
-    case QSysInfo::MV_10_3:
-        version.append("Mac OS X 10.3 (Panther)");
-        break;
-    case QSysInfo::MV_10_4:
-        version.append("Mac OS X 10.4 (Tiger)");
-        break;
-    case QSysInfo::MV_10_5:
-        version.append("Mac OS X 10.5 (Leopard)");
-        break;
-    case QSysInfo::MV_10_6:
-        version.append("Mac OS X 10.6 (Snowleopard)");
-        break;
-    case QSysInfo::MV_10_7:
-        version.append("Mac OS X 10.7 (Lion)");
-        break;
-    case QSysInfo::MV_10_8:
-        version.append("Mac OS X 10.8 (Mountainlion)");
-        break;
-    case QSysInfo::MV_10_9:
-        version.append("Mac OS X 10.9 (Mavericks)");
-        break;
-    default:
-        version.append(tr("Unknown Mac OS"));
-        break;
-    }
-#endif
-#ifdef Q_OS_LINUX
-    // Linux version
-    QProcess uname;
-    uname.start("uname -ro");
-    if (uname.waitForStarted()) {
-        if (uname.waitForFinished()) {
-            version.append(uname.readAll());
-        }
-    }
-#endif
+    version.append(QSysInfo::productType() + " " + QSysInfo::productVersion());
     systemLayout->addWidget(new QLabel(version));
     QString buildTime(QString(tr("Build time: %1 %2")).arg(__DATE__).arg(__TIME__));
     systemLayout->addWidget(new QLabel(buildTime));
