@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2005-2018 by                                                *
+ *  Copyright (C) 2005-2020 by                                                *
  *    Bjoern Erik Nilsen (bjoern.nilsen@bjoernen.com),                        *
  *    Fredrik Berg Kjoelstad (fredrikbk@hotmail.com),                         *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
@@ -269,9 +269,8 @@ void CameraControllerDialog::makeGUI()
 
     helpButton = new QPushButton(tr("Help"), this);
     helpButton->setDefault(false);
+    helpButton->setShortcut(QKeySequence::HelpContents);  // Fire clicked event
     connect(helpButton, SIGNAL(clicked()), this, SLOT(help()));
-    helpButton->setShortcut(QKeySequence::HelpContents);
-    connect(helpButton, SIGNAL(triggered()), this, SLOT(help()));
 
     closeButton = new QPushButton("closeButton");
     closeButton->setDefault(true);
@@ -595,10 +594,6 @@ void CameraControllerDialog::initialize()
         configureSlider(colorSlider, capabilities, intValue);
     }
 
-    if (qualityCount == 0) {
-        qualityGroupBox->hide();
-    }
-
     // -------------------------------------------------------------------------
     // Control controls
     // -------------------------------------------------------------------------
@@ -722,10 +717,6 @@ void CameraControllerDialog::initialize()
         configureSlider(rollSlider, capabilities, intValue);
     }
 
-    if (controlCount == 0) {
-        controlGroupBox->hide();
-    }
-
     closeButton->setFocus();
 
     qDebug() << "CameraControllerDialog::initialize --> End";
@@ -1743,7 +1734,7 @@ void CameraControllerDialog::changeAutoBrightness(int newState, bool save)
 
 void CameraControllerDialog::changeBrightness()
 {
-    int value = (int)(brightnessSlider->value());
+    int value = static_cast<int>(brightnessSlider->value());
 
     brightnessSlider->setToolTip(QString::number(value));
     changeBrightness(value, true);
@@ -1795,7 +1786,7 @@ void CameraControllerDialog::changeAutoContrast(int newState, bool save)
 
 void CameraControllerDialog::changeContrast()
 {
-    int value = (int)(contrastSlider->value());
+    int value = static_cast<int>(contrastSlider->value());
 
     contrastSlider->setToolTip(QString::number(value));
     changeContrast(value, true);
@@ -1847,7 +1838,7 @@ void CameraControllerDialog::changeAutoSaturation(int newState, bool save)
 
 void CameraControllerDialog::changeSaturation()
 {
-    int value = (int)(saturationSlider->value());
+    int value = static_cast<int>(saturationSlider->value());
 
     saturationSlider->setToolTip(QString::number(value));
     changeSaturation(value, true);
@@ -1899,7 +1890,7 @@ void CameraControllerDialog::changeAutoHue(int newState, bool save)
 
 void CameraControllerDialog::changeHue()
 {
-    int value = (int)(hueSlider->value());
+    int value = static_cast<int>(hueSlider->value());
 
     hueSlider->setToolTip(QString::number(value));
     changeHue(value, true);
@@ -1951,7 +1942,7 @@ void CameraControllerDialog::changeAutoGamma(int newState, bool save)
 
 void CameraControllerDialog::changeGamma()
 {
-    int value = (int)(gammaSlider->value());
+    int value = static_cast<int>(gammaSlider->value());
 
     gammaSlider->setToolTip(QString::number(value));
     changeGamma(value, true);
@@ -2003,7 +1994,7 @@ void CameraControllerDialog::changeAutoSharpness(int newState, bool save)
 
 void CameraControllerDialog::changeSharpness()
 {
-    int value = (int)(sharpnessSlider->value());
+    int value = static_cast<int>(sharpnessSlider->value());
 
     sharpnessSlider->setToolTip(QString::number(value));
     changeSharpness(value, true);
@@ -2055,7 +2046,7 @@ void CameraControllerDialog::changeAutoBacklight(int newState, bool save)
 
 void CameraControllerDialog::changeBacklight()
 {
-    int value = (int)(backlightSlider->value());
+    int value = static_cast<int>(backlightSlider->value());
 
     backlightSlider->setToolTip(QString::number(value));
     changeBacklight(value, true);
@@ -2107,7 +2098,7 @@ void CameraControllerDialog::changeAutoWhite(int newState, bool save)
 
 void CameraControllerDialog::changeWhite()
 {
-    int value = (int)(whiteSlider->value());
+    int value = static_cast<int>(whiteSlider->value());
 
     whiteSlider->setToolTip(QString::number(value));
     changeWhite(value, true);
@@ -2159,7 +2150,7 @@ void CameraControllerDialog::changeAutoGain(int newState, bool save)
 
 void CameraControllerDialog::changeGain()
 {
-    int value = (int)(gainSlider->value());
+    int value = static_cast<int>(gainSlider->value());
 
     gainSlider->setToolTip(QString::number(value));
     changeGain(value, true);
@@ -2211,7 +2202,7 @@ void CameraControllerDialog::changeAutoColor(int newState, bool save)
 
 void CameraControllerDialog::changeColor()
 {
-    int value = (int)(colorSlider->value());
+    int value = static_cast<int>(colorSlider->value());
 
     colorSlider->setToolTip(QString::number(value));
     changeColor(value, true);
@@ -2263,7 +2254,7 @@ void CameraControllerDialog::changeAutoExposure(int newState, bool save)
 
 void CameraControllerDialog::changeExposure()
 {
-    int value = (int)(exposureSlider->value());
+    int value = static_cast<int>(exposureSlider->value());
 
     exposureSlider->setToolTip(QString::number(value));
     changeExposure(value, true);
@@ -2315,7 +2306,7 @@ void CameraControllerDialog::changeAutoZoom(int newState, bool save)
 
 void CameraControllerDialog::changeZoom()
 {
-    int value = (int)(zoomSlider->value());
+    int value = static_cast<int>(zoomSlider->value());
 
     zoomSlider->setToolTip(QString::number(value));
     changeZoom(value, true);
@@ -2367,7 +2358,7 @@ void CameraControllerDialog::changeAutoFocus(int newState, bool save)
 
 void CameraControllerDialog::changeFocus()
 {
-    int value = (int)(focusSlider->value());
+    int value = static_cast<int>(focusSlider->value());
 
     focusSlider->setToolTip(QString::number(value));
     changeFocus(value, true);
@@ -2419,7 +2410,7 @@ void CameraControllerDialog::changeAutoPan(int newState, bool save)
 
 void CameraControllerDialog::changePan()
 {
-    int value = (int)(panSlider->value());
+    int value = static_cast<int>(panSlider->value());
 
     panSlider->setToolTip(QString::number(value));
     changePan(value, true);
@@ -2471,7 +2462,7 @@ void CameraControllerDialog::changeAutoTilt(int newState, bool save)
 
 void CameraControllerDialog::changeTilt()
 {
-    int value = (int)(tiltSlider->value());
+    int value = static_cast<int>(tiltSlider->value());
 
     tiltSlider->setToolTip(QString::number(value));
     changeTilt(value, true);
@@ -2523,7 +2514,7 @@ void CameraControllerDialog::changeAutoIris(int newState, bool save)
 
 void CameraControllerDialog::changeIris()
 {
-    int value = (int)(irisSlider->value());
+    int value = static_cast<int>(irisSlider->value());
 
     irisSlider->setToolTip(QString::number(value));
     changeIris(value, true);
@@ -2575,7 +2566,7 @@ void CameraControllerDialog::changeAutoRoll(int newState, bool save)
 
 void CameraControllerDialog::changeRoll()
 {
-    int value = (int)(rollSlider->value());
+    int value = static_cast<int>(rollSlider->value());
 
     rollSlider->setToolTip(QString::number(value));
     changeRoll(value, true);
@@ -2603,7 +2594,7 @@ void CameraControllerDialog::configureSlider(QwtSlider *slider, GrabberControlCa
     slider->setScalePosition(QwtSlider::LeadingScale);
     slider->setGroove(true);
 
-    slider->setScale((double)controlCaps->getMinimum(),(double)controlCaps->getMaximum());
+    slider->setScale(static_cast<double>(controlCaps->getMinimum()),static_cast<double>(controlCaps->getMaximum()));
     // slider->setSingleStep(controlCaps->getStep());
     // slider->setPageStep(controlCaps->getStep()/10);
     slider->setValue(value);
