@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2010-2015 by                                                *
+ *  Copyright (C) 2010-2020 by                                                *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
  *                                                                            *
  *  This program is free software; you can redistribute it and/or modify      *
@@ -57,9 +57,8 @@ DescriptionDialog::DescriptionDialog(Frontend *f, descriptionType type, QWidget
 
     helpButton = new QPushButton(tr("Help"), this);
     helpButton->setDefault(false);
+    helpButton->setShortcut(QKeySequence::HelpContents);  // Fire a clicked event
     connect(helpButton, SIGNAL(clicked()), this, SLOT(help()));
-    helpButton->setShortcut(QKeySequence::HelpContents);
-    connect(helpButton, SIGNAL(triggered()), this, SLOT(help()));
 
     QGridLayout *inputLayout = new QGridLayout;
     inputLayout->addWidget(projectDescrLabel, 0, 0);
