@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2010-2017 by                                                *
+ *  Copyright (C) 2010-2020 by                                                *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
  *                                                                            *
  *  This program is free software; you can redistribute it and/or modify      *
@@ -57,9 +57,7 @@ public:
     int getSelectedPossibility();
 
 private slots:
-    void newClick();
-    void lastClick();
-    void openClick();
+    void highlightSelection();
     void help();
 
 private:
