@@ -129,6 +129,12 @@ public:
      */
     void changeLanguage(int newIndex);
 
+    /**
+     * Getting all possible GUI styles
+     * @return A vector with all styles
+     */
+    static const QVector<QString> getStyles(Frontend* f);
+
     /**
      * A new capture button function is selected in the preferences menu.
      * @param newFunction New selected function.
@@ -373,7 +379,7 @@ public:
      * Get the recording mode.
      * @return The recording mode.
      */
-    int getRecordingMode();
+    enum DomainFacade::recordingMode getRecordingMode();
 
     /**
      * Set the recording mode.
@@ -808,6 +814,9 @@ private:
     QVector<QString>       translationsLanguages;
     QVector<QString>       translationsLocales;
 
+    // Style handling
+    int                    activeStyle;
+
     // Others
     QString                lastVisitedDir;
     ImageGrabberFacade    *grabber;
@@ -833,6 +842,11 @@ private:
      */
     void initTranslations();
 
+    /**
+     * Initialize the possible styles
+     */
+    void initStyles();
+
     /**
      * Creates key accelerators (keyboard shortcuts)
      *
