@@ -49,6 +49,7 @@ class GeneralWidget : public QWidget
 public:
 
     const static int    LANGUAGEDEFAULT       = 0;
+    const static int    STYLEDEFAULT          = 0;
     const static int    BUTTONFUNCTIONDEFAULT = PreferencesTool::captureButtonAfter;
     const static bool   VERTICALGRIDDEFAULT   = false;
     const static int    VERTICALSPINDEFAULT   = 5;
@@ -95,6 +96,12 @@ private slots:
      */
     void changeLanguage(int index);
 
+    /**
+     * Slot for notified the application when the style changes.
+     * @param index the new style.
+     */
+    void changeStyle(int index);
+
     /**
      * Slot for notified the general tab when bevor button is selected, so that
      * general preferences can be updated.
@@ -133,11 +140,18 @@ private slots:
      */
     void clickedGridColorButton();
 
+    /**
+     * Slot for display file dialog for selecting photo editor.
+     */
+    void choosePhotoEditor();
+
 private:
     Frontend     *frontend;
 
     QGroupBox    *languageGroupBox;
     QComboBox    *languageCombo;
+    QGroupBox    *styleGroupBox;
+    QComboBox    *styleCombo;
     QGroupBox    *captureGroupBox;
     QRadioButton *bevorButton;
     QRadioButton *afterButton;
@@ -151,8 +165,13 @@ private:
     QPushButton  *gridColorButton;
     QGroupBox    *signalGroupBox;
     QCheckBox    *signalCheck;
+    QGroupBox    *photoEditorBox;
+    QLabel       *photoEditorLabel;
+    QLineEdit    *photoEditorEdit;
+    QPushButton  *photoEditorButton;
 
     int           actualLanguage;
+    int           actualStyle;
     int           actualButtonFunction;
     bool          actualVerticalGrid;
     int           actualVerticalSpin;
@@ -161,6 +180,7 @@ private:
     QColor        actualGridColor;
     QColor        newGridColor;
     bool          actualSignal;
+    QString       actualPhotoEditorPath;
 };
 
 #endif
