@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2005-2016 by                                                *
+ *  Copyright (C) 2005-2020 by                                                *
  *    Bjoern Erik Nilsen (bjoern.nilsen@bjoernen.com),                        *
  *    Fredrik Berg Kjoelstad (fredrikbk@hotmail.com),                         *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
@@ -29,9 +29,9 @@
 
 #define MIN_TREE_WIDTH   300
 #define MAX_TREE_WIDTH   MIN_TREE_WIDTH
-#define MIN_PAGE_WIDTH   600
+#define MIN_PAGE_WIDTH   650
 #define MAX_PAGE_WIDTH   MIN_PAGE_WIDTH
-#define MIN_PAGE_HEIGHT  500
+#define MIN_PAGE_HEIGHT  550
 #define MAX_PAGE_HEIGHT  MIN_PAGE_HEIGHT
 
 
@@ -41,14 +41,14 @@ ProjectDialog::ProjectDialog(Frontend *f, QWidget *parent)
     qDebug() << "ProjectDialog::Constructor --> Start";
 
     frontend               = f;
-    pageTree                = 0;
-    pageLayout              = 0;
-    // generalSettingsPage     = 0;
-    // projectValuePage        = 0;
-    imageImportPage         = 0;
-    imageTransformationPage = 0;
-    videoExportPage         = 0;
-    // grabberSelectPage       = 0;
+    pageTree                = nullptr;
+    pageLayout              = nullptr;
+    // generalSettingsPage     = nullptr;
+    // projectValuePage        = nullptr;
+    imageImportPage         = nullptr;
+    imageTransformationPage = nullptr;
+    videoExportPage         = nullptr;
+    // grabberSelectPage       = nullptr;
     activePage              = 0;
 
     pageTree = new QTreeWidget();
@@ -69,9 +69,8 @@ ProjectDialog::ProjectDialog(Frontend *f, QWidget *parent)
 
     helpButton = new QPushButton(tr("Help"), this);
     helpButton->setDefault(false);
+    helpButton->setShortcut(QKeySequence::HelpContents);  // Fire clicked event
     connect(helpButton, SIGNAL(clicked()), this, SLOT(help()));
-    helpButton->setShortcut(QKeySequence::HelpContents);
-    connect(helpButton, SIGNAL(triggered()), this, SLOT(help()));
 
     applyButton = new QPushButton(tr("Apply"), this);
     applyButton->setDefault(false);
@@ -245,7 +244,7 @@ void ProjectDialog::itemClicked(QTreeWidgetItem *pageItem,
 
     activePage = 0;
 
-    if (NULL != pageItem->parent())
+    if (nullptr != pageItem->parent())
     {
         activePage = pageItem->parent()->indexOfChild(pageItem);
     }
