@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2005-2015 by                                                *
+ *  Copyright (C) 2005-2020 by                                                *
  *    Bjoern Erik Nilsen (bjoern.nilsen@bjoernen.com),                        *
  *    Fredrik Berg Kjoelstad (fredrikbk@hotmail.com),                         *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
@@ -49,7 +49,7 @@ public:
      * @param f frontend of the application.
      * @param parent the parent of the widget.
      */
-    ProjectDialog(Frontend *f, QWidget *parent = 0);
+    ProjectDialog(Frontend *f, QWidget *parent = nullptr);
 
 private:
     Frontend        *frontend;
