@@ -36,7 +36,7 @@
 #include <QToolBox>
 #include <QWidget>
 
-#include <qwt/qwt_slider.h>
+#include <qwt_slider.h>
 
 #include "domain/domainfacade.h"
 
