@@ -27,7 +27,7 @@
 #include <QTimer>
 #include <QWidget>
 
-#include <qwt/qwt_slider.h>
+#include <qwt_slider.h>
 
 #include "frontends/frontend.h"
 
