@@ -301,8 +301,8 @@ void RecordingTab::retranslateStrings()
 
     recordingGroupBox->setTitle(tr("Recording mode"));
     recordingModeCombo->clear();
-    recordingModeCombo->addItem(tr("Single frame capture"));
-    recordingModeCombo->addItem(tr("Time-lapse capture"));
+    recordingModeCombo->addItem(tr("Single frame capture"), DomainFacade::singleFrameMode);
+    recordingModeCombo->addItem(tr("Time-lapse capture"), DomainFacade::timeLapseMode);
 
     captureGroupBox->setTitle(tr("Capture"));
     mixModeCombo->clear();
@@ -480,9 +480,30 @@ bool RecordingTab::setResolution(int index)
 }
 
 
-int RecordingTab::getRecordingMode()
+enum DomainFacade::recordingMode RecordingTab::getRecordingMode()
 {
-    return recordingModeCombo->currentIndex();
+    const QVariant userData = recordingModeCombo->currentData();
+    if (!userData.isValid()) {
+        qWarning() << "recordingModeCombo contains invalid data for index"
+                   << recordingModeCombo->currentIndex()
+                   << "use singleFrameMode";
+        return DomainFacade::singleFrameMode;
+    }
+
+    bool ok = false;
+    const int mode = userData.toInt(&ok);
+    if (!ok || (mode < DomainFacade::singleFrameMode)
+            || (mode > DomainFacade::timeLapseMode)) {
+        qWarning() << "recordingModeCombo contains invalid data for index"
+                   << recordingModeCombo->currentIndex()
+                   << "current data:" << userData
+                   << "use singleFrameMode";
+        return DomainFacade::singleFrameMode;
+    }
+
+    const enum DomainFacade::recordingMode recMode
+            = static_cast<enum DomainFacade::recordingMode>(mode);
+    return recMode;
 }
 
 
@@ -554,9 +575,12 @@ int RecordingTab::getUnitMode()
 
 void RecordingTab::setUnitMode(int mode)
 {
-    Q_ASSERT(mode >= DomainFacade::secondsMode);
-    Q_ASSERT(mode < DomainFacade::lastUnitMode);
-
+    if ((mode < DomainFacade::secondsMode) || (mode >= DomainFacade::lastUnitMode)) {
+        qCritical() << "try to set invalid timelapse unit mode" << mode;
+        qCritical() << "use units in seconds";
+        mode = DomainFacade::secondsMode;
+    }
+    qDebug() << "set timelapse unit mode to" << mode;
     unitModeCombo->setCurrentIndex(mode);
     changeUnitMode(mode);
 }
@@ -564,7 +588,7 @@ void RecordingTab::setUnitMode(int mode)
 
 int RecordingTab::getUnitCount()
 {
-    if (unitModeCombo->currentIndex() == 0) {
+    if (unitModeCombo->currentIndex() == DomainFacade::secondsMode) {
         return (int)(unitCountSlider->value());
     }
     else {
@@ -572,11 +596,41 @@ int RecordingTab::getUnitCount()
     }
 }
 
+quint64 RecordingTab::getTimelapseIntervalMsec() const
+{
+    quint64 factor = 1000;
+
+    switch (unitModeCombo->currentIndex()) {
+    case DomainFacade::secondsMode:
+        factor = 1000;
+        break;
+    case DomainFacade::minutesMode:
+        factor = 60000;
+        break;
+    case DomainFacade::hoursMode:
+        factor = 3600000;
+        break;
+    case DomainFacade::daysMode:
+        factor = 86400000;
+        break;
+    default:
+        qCritical() << "couldn't select timelapse unit mode. combobox index:" << unitModeCombo->currentIndex()
+                    << "use factor 1000";
+        break;
+    }
+
+    const quint64 msec = static_cast<quint64>(unitCountSlider->value()) * factor;
+    return msec;
+}
+
 
 void RecordingTab::setUnitCount(int count)
 {
-    unitCountSlider->setValue((double)count);
-    unitCountSliderValue->setText(QString("%1").arg(count));
+    qDebug() << "set timelapse unit count to" << count;
+    unitCountSlider->setValue(static_cast<double>(count));
+    unitCountSliderValue->setText(QString::number(count));
+
+    boundBeepTimeSlider();
 }
 
 
@@ -604,7 +658,7 @@ void RecordingTab::setBeepState(bool checked)
 
 int RecordingTab::getBeepCount()
 {
-    if (unitModeCombo->currentIndex() == 0) {
+    if (unitModeCombo->currentIndex() == DomainFacade::secondsMode) {
         return (int)(beepCountSlider->value());
     }
     else {
@@ -615,8 +669,8 @@ int RecordingTab::getBeepCount()
 
 void RecordingTab::setBeepCount(int count)
 {
-    beepCountSlider->setValue((double)count);
-    beepCountSliderValue->setText(QString("%1").arg(count));
+    qDebug() << "set timelapse beep timer interval to" << count << "second(s)";
+    boundBeepTimeSlider(count);
 }
 
 
@@ -733,12 +787,13 @@ void RecordingTab::changeUnitMode(int index)
     qDebug() << "RecordingTab::changeUnitMode --> Start";
 
     // frontend->getProject()->getAnimationProject()->setUnitMode(index);
+    qDebug() << "change timelapse timer unit mode to" << index;
 
     switch (index) {
     case DomainFacade::secondsMode:
         // Seconds
         unitCountSliderCaption->setText(tr("Seconds between pictures"));
-        unitCountSlider->setScale(0, 60);
+        unitCountSlider->setScale(1, 60);
         unitCountSlider->setTotalSteps(60);
         unitCountSlider->setValue(30);
 
@@ -746,7 +801,7 @@ void RecordingTab::changeUnitMode(int index)
     case DomainFacade::minutesMode:
         // Minutes
         unitCountSliderCaption->setText(tr("Minutes between pictures"));
-        unitCountSlider->setScale(0, 60);
+        unitCountSlider->setScale(1, 60);
         unitCountSlider->setTotalSteps(60);
         unitCountSlider->setValue(5);
 
@@ -754,7 +809,7 @@ void RecordingTab::changeUnitMode(int index)
     case DomainFacade::hoursMode:
         // Hours
         unitCountSliderCaption->setText(tr("Hours between pictures"));
-        unitCountSlider->setScale(0, 25);
+        unitCountSlider->setScale(1, 25);
         unitCountSlider->setTotalSteps(25);
         unitCountSlider->setValue(1);
 
@@ -762,16 +817,19 @@ void RecordingTab::changeUnitMode(int index)
     case DomainFacade::daysMode:
         // Days
         unitCountSliderCaption->setText(tr("Days between pictures"));
-        unitCountSlider->setScale(0, 30);
+        unitCountSlider->setScale(1, 30);
         unitCountSlider->setTotalSteps(30);
         unitCountSlider->setValue(1);
 
         break;
     }
 
+    const int unitCount = static_cast<int>(unitCountSlider->value());
+    unitCountSliderValue->setText(QString::number(unitCount));
     if (frontend->getProject()->isActiveProject()) {
         frontend->getProject()->getAnimationProject()->setUnitMode(index);
     }
+    boundBeepTimeSlider();
 
     qDebug() << "RecordingTab::changeUnitMode --> End";
 }
@@ -781,61 +839,19 @@ void RecordingTab::changeUnitCount()
 {
     qDebug() << "RecordingTab::changeUnitCount --> Start";
 
-    int newUnitCount = (int)unitCountSlider->value();
-    int factor = 0;
-    int unitMode = unitModeCombo->currentIndex();
+    int newUnitCount = static_cast<int>(unitCountSlider->value());
 
     if (0 == newUnitCount) {
         newUnitCount = 1;
     }
 
-    /*
-    switch (unitMode) {
-    case DomainFacade::secondsMode:
-        if (60 < newUnitCount) {
-            newUnitCount = 60;
-        }
-        break;
-    case DomainFacade::minutesMode:
-        if (60 < newUnitCount) {
-            newUnitCount = 60;
-        }
-        break;
-    case DomainFacade::hoursMode:
-        if (24 < newUnitCount) {
-            newUnitCount = 24;
-        }
-        break;
-    case DomainFacade::daysMode:
-        if (30 < newUnitCount) {
-            newUnitCount = 30;
-        }
-        break;
-    }
-    */
     if (frontend->getProject()->isActiveProject()) {
         frontend->getProject()->getAnimationProject()->setUnitCount(newUnitCount);
     }
-    unitCountSliderValue->setText(QString("%1").arg(newUnitCount));
-    /*
-    if (newUnitCount == 0 || unitMode == DomainFacade::secondsMode) {
-        if (timelapseTimer->isActive()) {
-            timelapseTimer->stop();
-        }
-        return;
-    }
-
-    if (timelapseTimer->isActive() == false) {
-        // Grab the first frame manually
-        cameraHandler->captureFrame();
-        // then grab at the given interval
-        timelapseTimer->start(factor / newUnitCount);
-    }
-    else {
-        timelapseTimer->setInterval(factor / newUnitCount);
-    }
-    */
+    unitCountSliderValue->setText(QString::number(newUnitCount));
+    qDebug() << "timelapse grab interval changed to" << newUnitCount << "sec";
 
+    boundBeepTimeSlider();
     qDebug() << "RecordingTab::changeUnitCount --> End";
 }
 
@@ -868,14 +884,15 @@ void RecordingTab::changeBeepCount()
 {
     qDebug() << "RecordingTab::changeBeepCount --> Start";
 
-    int newBeepCount = (int)beepCountSlider->value();
+    int newBeepCount = static_cast<int>(beepCountSlider->value());
 
     if (0 == newBeepCount) {
         newBeepCount = 1;
     }
 
+    qDebug() << "change timelapse beep timer interval to" << newBeepCount << "second(s)";
     frontend->getProject()->getAnimationProject()->setBeepCount(newBeepCount);
-    beepCountSliderValue->setText(QString("%1").arg(newBeepCount));
+    beepCountSliderValue->setText(QString::number(newBeepCount));
 
     qDebug() << "RecordingTab::changeBeepCount --> End";
 }
@@ -969,11 +986,13 @@ void RecordingTab::cameraButtonClicked()
             clickSoundFile.append(QLatin1String("click.wav"));
 
             clickEffect = new QSoundEffect();
+            connect(clickEffect, SIGNAL(statusChanged()),
+                    this, SLOT(checkSoundEffectStatus()));
             clickEffect->setSource(QUrl::fromLocalFile(clickSoundFile));
             clickEffect->setVolume(0.25f);
         }
 
-        if (0 == getRecordingMode()) {
+        if (DomainFacade::singleFrameMode == getRecordingMode()) {
             // Capture mode
 
             toolBar->setActualState(ToolBar::toolBarCameraOn);
@@ -981,9 +1000,6 @@ void RecordingTab::cameraButtonClicked()
         else {
             // Time lapse mode
 
-            int msec;
-            int factor;
-
             if (beepCheckBox->isChecked()) {
                 // Create timer for the time between beep and frame capture
                 cameraTimer = new QTimer(this);
@@ -994,6 +1010,8 @@ void RecordingTab::cameraButtonClicked()
                 beepSoundFile.append(QLatin1String("beep.wav"));
 
                 beepEffect = new QSoundEffect();
+                connect(beepEffect, SIGNAL(statusChanged()),
+                        this, SLOT(checkSoundEffectStatus()));
                 beepEffect->setSource(QUrl::fromLocalFile(beepSoundFile));
                 beepEffect->setVolume(0.25f);
             }
@@ -1003,46 +1021,17 @@ void RecordingTab::cameraButtonClicked()
             timelapseTimer->setSingleShot(false);
             QObject::connect(timelapseTimer, SIGNAL(timeout()), this, SLOT(sendBeep()));
 
-            // Calculate the time between the beeps
-            switch (unitModeCombo->currentIndex()) {
-            case DomainFacade::secondsMode:
-                // Seconds
-                factor = 1000;
-
-                break;
-            case DomainFacade::minutesMode:
-                // Minutes
-                factor = 60000;
-
-                break;
-            case DomainFacade::hoursMode:
-                // Hours
-                factor = 3600000;
-
-                break;
-            case DomainFacade::daysMode:
-                // Days
-                factor = 86400000;
-
-                break;
-            default:
-                if (timelapseTimer->isActive()) {
-                    timelapseTimer->stop();
-                }
-                break;
-            }
-
-            msec = unitCountSlider->value() * factor;
-
             // Start the time lapse time
-            timelapseTimer->start(msec);
+            quint64 msec = getTimelapseIntervalMsec();
+            qDebug() << "start timelapse timer with interval" << msec << "msec";
+            timelapseTimer->start(static_cast<int>(msec));
         }
     }
     else {
         // captureGroupBox->hide();
         enableCaptureGroupBox(true);
         enableTimelapseGroupBox(true);
-        if (0 == getRecordingMode()) {
+        if (DomainFacade::singleFrameMode == getRecordingMode()) {
             // Capture mode
 
             toolBar->setActualState(ToolBar::toolBarCameraOff);
@@ -1124,7 +1113,9 @@ void RecordingTab::sendBeep()
         beepEffect->play();
 
         // Start the timer for the frame capture
-        cameraTimer->start(beepCountSlider->value() * 1000);
+        const int ms = beepCountSlider->value() * 1000;
+        qDebug() << "start timelapse beep timer with interval" << ms << "msec";
+        cameraTimer->start(ms);
     }
     else
     {
@@ -1139,9 +1130,14 @@ void RecordingTab::sendBeep()
 
 void RecordingTab::captureFrame()
 {
+    if (!cameraOn) {
+        // skip capturing when camera hasn't been activated yet
+        return;
+    }
+
     qDebug() << "RecordingTab::captureFrame --> Start";
 
-    if (0 == getRecordingMode()) {
+    if (DomainFacade::singleFrameMode == getRecordingMode()) {
         // Capture mode
 
         toolBar->setActualState(ToolBar::toolBarNothing);
@@ -1149,7 +1145,7 @@ void RecordingTab::captureFrame()
 
     storeFrame();
 
-    if (0 == getRecordingMode()) {
+    if (DomainFacade::singleFrameMode == getRecordingMode()) {
         // Capture mode
 
         toolBar->setActualState(ToolBar::toolBarCameraOn);
@@ -1210,6 +1206,22 @@ void RecordingTab::storeFrame()
 }
 
 
+void RecordingTab::checkSoundEffectStatus()
+{
+    const QSoundEffect *effect = qobject_cast<const QSoundEffect *>(sender());
+    if (!effect) {
+        qCritical() << "slot checkSoundEffectStatus() was called from unexpected sender:"
+                    << sender();
+        return;
+    }
+
+    if (effect->status() == QSoundEffect::Error) {
+        qCritical() << "an error was occured for sound effect" << effect->source();
+        qCritical() << "verify the sound file's location";
+    }
+}
+
+
 QImage RecordingTab::clipAndScale(QImage image)
 {
     QImage outputImage;
@@ -1385,3 +1397,41 @@ void RecordingTab::enableTimelapseGroupBox(bool newState)
 
     qDebug() << "RecordingTab::enableTimelapseGroupBox --> End";
 }
+
+void RecordingTab::boundBeepTimeSlider(int newBeepIntervalSec)
+{
+    const quint64 timelapseIntervalMs = getTimelapseIntervalMsec();
+    quint64 beepIntervalMs = static_cast<quint64>(beepCountSlider->value()) * 1000;
+    if (newBeepIntervalSec == -1) {
+        beepIntervalMs = static_cast<quint64>(newBeepIntervalSec) * 1000;
+    }
+
+    // Rescale beep count slider according to timelapse grabbing interval
+    qint64 maxBeepInterval = timelapseIntervalMs / 1000 - 1;
+    if (maxBeepInterval <= 0) {
+        qWarning() << "timelapse interval is less than 1 second. set beep interval to 1sec";
+        maxBeepInterval = 1;
+    }
+    if (maxBeepInterval > 100) {
+        maxBeepInterval = 100;
+    }
+    beepCountSlider->setScale(1, maxBeepInterval);
+    beepCountSlider->setTotalSteps(static_cast<uint>(maxBeepInterval));
+
+    // Reduce beep interval if it greater than timelaplse grabbing interval
+    int newBeepCount = -1;
+    if (beepIntervalMs >= timelapseIntervalMs) {
+        qDebug() << "reduce timelapse beep interval to 1000msec because current value greater than grabbing interval:"
+                 << beepIntervalMs << timelapseIntervalMs;
+        newBeepCount = 1;
+    } else if (newBeepIntervalSec == -1) {
+        newBeepCount = newBeepIntervalSec;
+    }
+    if (newBeepCount > 0) {
+        beepCountSlider->setValue(static_cast<double>(newBeepCount));
+        beepCountSliderValue->setText(QString::number(newBeepCount));
+        if (frontend->getProject() && frontend->getProject()->getAnimationProject()) {
+            frontend->getProject()->getAnimationProject()->setBeepCount(newBeepCount);
+        }
+    }
+}
