@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2010-2018 by                                                *
+ *  Copyright (C) 2010-2020 by                                                *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
  *                                                                            *
  *  This program is free software; you can redistribute it and/or modify      *
@@ -800,25 +800,15 @@ int GphotoGrabber::lookupWidget(CameraWidget  *widget,
  * @brief GphotoGrabber::errorDumper
  * @param level
  * @param domain
- * @param format
- * @param args
+ * @param str
  * @param data
  */
 void GphotoGrabber::errorDumper(GPLogLevel  level,
                                 const char *domain,
-                                const char *format,
-                                va_list     args,
+                                const char *str,
                                 void       *data)
 {
-    char temp[1024];
-
-    if (args != NULL) {
-        vsprintf(temp, format, args);
-        qDebug() << "GphotoGrabber::errorDumper --> Domain: " << domain << "Error: " << temp;
-    }
-    else {
-        qDebug() << "GphotoGrabber::errorDumper --> Domain: " << domain << "Error: " << format;
-    }
+    qDebug() << "GphotoGrabber::errorDumper --> Domain: " << domain << "Error: " << str;
 }
 
 
@@ -877,6 +867,7 @@ bool GphotoGrabber::canonEnableCapture(Camera       *gphotoCamera,
         return false;
     }
 
+    return true;
 }
 
 
