@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2010-2018 by                                                *
+ *  Copyright (C) 2010-2020 by                                                *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
  *                                                                            *
  *  This program is free software; you can redistribute it and/or modify      *
@@ -44,8 +44,9 @@ V4L2Grabber::V4L2Grabber(Frontend *f)
 
     fd = -1;
     errno = -1;
-    dst_buf = NULL;
-    frameData = NULL;
+    dst_buf = nullptr;
+    frameData = nullptr;
+    firstImage = true;
 
     qDebug() << "V4L2Grabber::Constructor --> End";
 }
@@ -79,8 +80,8 @@ bool V4L2Grabber::initialization(QVector<ImageGrabberDevice*> &devices)
         QString              deviceName = QString("%1%2")
                                           .arg(QLatin1String("/dev/video"))
                                           .arg(i);
-        ImageGrabberDevice*  device = NULL;
-        V4L2Controller*      deviceController = NULL;
+        ImageGrabberDevice*  device = nullptr;
+        V4L2Controller*      deviceController = nullptr;
         bool                 ret;
 
         // fd = open(deviceName.toAscii(), O_RDONLY);
@@ -113,7 +114,7 @@ bool V4L2Grabber::initialization(QVector<ImageGrabberDevice*> &devices)
         else {
             // Delete the new device
             delete device;
-            device = NULL;
+            device = nullptr;
         }
 
         // close(fd);
@@ -229,7 +230,7 @@ bool V4L2Grabber::setUp()
 
 
     if (xioctl(fd, VIDIOC_S_FMT, &format) < 0) {
-        qDebug() << "V4L2Grabber::setUp --> Error: Can't set capture format";
+        qDebug() << "frameDataV4L2Grabber::setUp --> Error: Can't set capture format";
         goto Error;
     }
     if (format.fmt.pix.pixelformat != pixelFormat) {
@@ -270,7 +271,7 @@ bool V4L2Grabber::setUp()
         }
 
         buffers[i].length = buf.length;
-        // buffers[i].start = mmap(NULL, buf.length, PROT_READ | PROT_WRITE, MAP_SHARED, fd, buf.m.offset);
+        // buffers[i].start = mmap(nullptr, buf.length, PROT_READ | PROT_WRITE, MAP_SHARED, fd, buf.m.offset);
         buffers[i].start = (void*)v4l2_mmap(0, buf.length, PROT_READ | PROT_WRITE, MAP_SHARED, fd, buf.m.offset);
         if (buffers[i].start == MAP_FAILED) {
             qDebug() << "V4L2Grabber::setUp --> Error: Unable to map buffer (" << strerror(errno) << ")";  // Error see mmap man page
@@ -301,9 +302,9 @@ bool V4L2Grabber::setUp()
     return true;
 
 Error:
-    if (dst_buf != NULL) {
+    if (dst_buf != nullptr) {
         free(dst_buf);
-        dst_buf = NULL;
+        dst_buf = nullptr;
     }
     if (fd > -1) {
         // close(fd);
@@ -341,7 +342,7 @@ const QImage V4L2Grabber::getImage()
         return image;
     }
 
-    unsigned char*  pixels = NULL;
+    unsigned char*  pixels = nullptr;
     unsigned int    nBytes = 0;
 
     // Save the image.
@@ -505,9 +506,9 @@ const QImage V4L2Grabber::getImage()
         imageLoaded = 1;
     }
 
-    if (NULL != pixels) {
+    if (nullptr != pixels) {
         free(pixels);
-        pixels = NULL;
+        pixels = nullptr;
     }
 
     if (firstImage) {
@@ -557,13 +558,13 @@ bool V4L2Grabber::tearDown()
         v4l2_munmap(buffers[i].start, buffers[i].length);
     }
 
-    if (frameData != NULL) {
-        delete frameData;
-        frameData = NULL;
+    if (frameData != nullptr) {
+        delete[] frameData;
+        frameData = nullptr;
     }
-    if (dst_buf != NULL) {
+    if (dst_buf != nullptr) {
         free(dst_buf);
-        dst_buf = NULL;
+        dst_buf = nullptr;
     }
     if (fd > -1) {
         // close(fd);
@@ -642,6 +643,8 @@ bool V4L2Grabber::enumerateCaptureFormats(int fd, ImageGrabberDevice *device)
 
         frmsize.pixel_format = fmt.pixelformat;
         frmsize.index = 0;
+        frmsize.reserved[0] = 0;
+        frmsize.reserved[1] = 0;
         while (xioctl(fd, VIDIOC_ENUM_FRAMESIZES, &frmsize) >= 0) {
             switch (frmsize.type) {
             case V4L2_FRMSIZE_TYPE_DISCRETE:
@@ -732,7 +735,7 @@ bool V4L2Grabber::enumerateCaptureFormats(int fd, ImageGrabberDevice *device)
 }
 
 
-int V4L2Grabber::xioctl(int fd, int IOCTL_X, void *arg)
+int V4L2Grabber::xioctl(int fd, unsigned long IOCTL_X, void *arg)
 {
     // qDebug() << "V4L2Grabber::xioctl --> Start";
 
