@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2005-2018 by                                                *
+ *  Copyright (C) 2005-2019 by                                                *
  *    Bjoern Erik Nilsen (bjoern.nilsen@bjoernen.com),                        *
  *    Fredrik Berg Kjoelstad (fredrikbk@hotmail.com),                         *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
@@ -34,8 +34,8 @@
 
 const QString PreferencesTool::applicationShowName = QLatin1String("qStopMotion");
 const QString PreferencesTool::applicationName = QLatin1String("qstopmotion");
-const QString PreferencesTool::applicationVersion = QLatin1String("2.4.1");
-const QString PreferencesTool::applicationYear = QLatin1String("2018");
+const QString PreferencesTool::applicationVersion = QLatin1String("2.5.2");
+const QString PreferencesTool::applicationYear = QLatin1String("2021");
 const QString PreferencesTool::preferencesVersion = QLatin1String("0.9");
 const QString PreferencesTool::preferencesSuffix = QLatin1String("qsmp");
 const QString PreferencesTool::preferencesName = QLatin1String("preferences");
@@ -52,6 +52,7 @@ const QString PreferencesTool::graphicsDirectory = QLatin1String("graphics");
 const QString PreferencesTool::iconsDirectory = QLatin1String("icons");
 const QString PreferencesTool::picturesDirectory = QLatin1String("pictures");
 const QString PreferencesTool::soundsDirectory = QLatin1String("sounds");
+const QString PreferencesTool::stylesDirectory = QLatin1String("styles");
 const QString PreferencesTool::historyFileName = QLatin1String(".history");
 
 const QString PreferencesTool::jpegSuffix = QLatin1String("jpg");
@@ -170,6 +171,9 @@ bool PreferencesTool::setPreferencesFile(const QString &filePath, const QString
         qWarning() << "PreferencesTool::setPreferencesFile --> Error while parsing preferences file";
         goto FileCorrupt;
     }
+
+    qDebug() << "PreferencesTool::setPreferencesFile --> End";
+
     return true;
 
 FileCorrupt:
@@ -199,7 +203,7 @@ FileCorrupt:
 
     flushPreferences();
 
-    qDebug() << "PreferencesTool::setPreferencesFile --> End";
+    qDebug() << "PreferencesTool::setPreferencesFile --> File Corrupt End";
 
     return false;
 }
@@ -424,7 +428,8 @@ PreferencesElement* PreferencesTool::findPreferencesElement(const QString &name)
 void PreferencesTool::setBasicPreferenceDefaults()
 {
     // General defaults
-    setStringPreference("preferences", "language", "en");
+    setStringPreference("preferences", "language", "en");     // English
+    setIntegerPreference("preferences", "style", 0);          // No style
     setIntegerPreference("preferences", "capturebutton", captureButtonAfter);
     // Project defaults
     setIntegerPreference("preferences", "defaultrecordingmode", DomainFacade::RECORDINGMODEDEFAULT);
@@ -449,6 +454,7 @@ void PreferencesTool::setBasicPreferenceDefaults()
     setIntegerPreference("preferences", "defaultvideoformat", DomainFacade::VIDEOFORMATDEFAULT);
     setIntegerPreference("preferences", "defaultvideosize", DomainFacade::VIDEOSIZEDEFAULT);
     setIntegerPreference("preferences", "defaultvideofps", DomainFacade::VIDEOFPSDEFAULT);
+    setBooleanPreference("preferences", "defaultmovieexportsplittingmode", DomainFacade::MOVIESPLITTINGMODEDEFAULT);
     setBooleanPreference("preferences", "defaultusedefaultoutputfile", DomainFacade::USEDEFAULTOUTPUTFILENAMEDEFAULT);
     // Grabber defaults
     setBooleanPreference("preferences", "v4l2grabber", Frontend::V4L2GRABBERDEFAULT);
