@@ -60,11 +60,26 @@ public:
 
     /**
      * Gets the arguments for the encoder.
+     * @param inputFilelistPath path to file, which contain list of input files
+     * @param outputDirectory path to folder, where output files must be stored
      * @return the encoder argument list
      */
-    const QStringList getEncoderArguments() const;
+    const QStringList getEncoderArguments(const QString inputFilelistPath,
+                                          const QString outputDirectory) const;
+
+    /**
+     * Create files which contains lists of input files.
+     * @param moviesFiles information about images which will united in movie.
+     * key - generated movie's path, values - exposures list.
+     * @param tmpDir path to the application's temporary directory
+     * @return list of paths to input filelists
+     */
+    const QStringList createInputFilelists(QMap<QString, QStringList> moviesFiles, QString tmpDir) const;
 
 private:
+    const QStringList inputOptions() const;
+    const QStringList outputOptions(const QString &movieName) const;
+
     AnimationProject *animationProject;
 };
 
